@@ -30,7 +30,7 @@ class BitcoinCLICached:
                 if "hdkeypath" in address_info:
                     path = address_info["hdkeypath"].split('/')
                     change = int(path[-2]) == 1
-                    while int(path[-1]) > wallet._dict["change_index" if change else "address_index"]:
+                    while int(path[-1]) > (wallet.change_index if change else wallet.address_index):
                         wallet.getnewaddress(change=change)
             if not scanning:
                 self.cache.scanning_ended()
@@ -64,7 +64,7 @@ class BitcoinCLICached:
         except RpcError as rpce:
             raise rpce
         except Exception as e:
-                raise e
+            raise e
     
     def listtransactions(self, *args, **kwargs):
         cli_transactions = self.cli.listtransactions(*args, **kwargs)
